(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     36321,        745]
NotebookOptionsPosition[     36494,        731]
NotebookOutlinePosition[     37215,        756]
CellTagsIndexPosition[     37172,        753]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Free Body Diagram of Beam\n",
 StyleBox["Qingchang Liu, Baoxing Xu \nUniversity of Virginia, 2017-09-16",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "1f0b3856-036c-4559-ac86-a359a58bd3e2"],

Cell["\<\
Successful application of the equations of equilibrium requires a complete \
specification of all the known and unknown external forces that act on the \
body. The best way to account for these forces is to draw a free-body \
diagram. This diagram is a sketch of the outlined shape of the body, which \
represents it as being isolated or \[OpenCurlyDoubleQuote]free\
\[CloseCurlyDoubleQuote] from its surroundings, i.e., a \
\[OpenCurlyDoubleQuote]free body.\[CloseCurlyDoubleQuote] On this sketch it \
is necessary to show all the forces and couple moments that the surroundings \
exert on the body so that these effects can be accounted for when the \
equations of equilibrium are applied.
\[FilledCircle] If a support prevents the translation of a body in a given \
direction, then a force is developed on the body in that direction.           \
                                                                              \
                         \[FilledCircle] If rotation is prevented, a couple \
moment is exerted on the body.\
\>", "Text",
 ExpressionUUID -> "50edfe98-c88f-49cd-b9d2-e658b33bf322"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`Lp$$ = 0.5, $CellContext`mg$$ = 
    1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 1, $CellContext`opa3$$ =
     1, $CellContext`opa4$$ = 0, $CellContext`opa5$$ = 
    0, $CellContext`sita$$ = 90, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Coordinates visibility", 
         Spacer[60]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[$CellContext`opa2$$], 1, 
       Row[{"Types of Beam", 
         Spacer[90]}]}, {1 -> "Cantilever", 0 -> "Simple-Supported"}}, {{
       Hold[$CellContext`opa3$$], 1, 
       Row[{"Types of Loading", 
         Spacer[78]}]}, {1 -> "Force", 0 -> "Moment"}}, {{
       Hold[$CellContext`Lp$$], 0.5, 
       Row[{"Position of Loading [m]", 
         Spacer[50]}]}, 0, 1}, {{
       Hold[$CellContext`mg$$], 1, 
       Row[{"Magnitude of Loading [kN]", 
         Spacer[28]}]}, 0, 2}, {{
       Hold[$CellContext`mg$$], 1, 
       Row[{"Magnitude of Loading [kN\[CenterDot]m]", 
         Spacer[15]}]}, 0, 2}, {{
       Hold[$CellContext`sita$$], 90, 
       Row[{"Direction of Force [\[Degree]]", 
         Spacer[63]}]}, 0, 360}, {{
       Hold[$CellContext`sita$$], 90, 
       Row[{"Direction of Force [\[Degree]]", 
         Spacer[63]}]}, 0, 180}, {{
       Hold[$CellContext`opa4$$], 1, 
       Row[{"Direction of Moment", 
         Spacer[55]}]}, {1 -> "CCW", 0 -> "CW"}}, {{
       Hold[$CellContext`opa4$$], 0, 
       Row[{"Direction of Moment", 
         Spacer[55]}]}, {0 -> "CW"}}, {{
       Hold[$CellContext`opa5$$], 0, 
       Row[{"Reactive Force & Moment", 
         Spacer[28]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[5]}], 0 -> Column[{
               Manipulate`Place[6]}]}, 
           Dynamic[$CellContext`opa3$$]]}, {
          PaneSelector[{1 -> PaneSelector[{1 -> Column[{
                  Manipulate`Place[7]}], 0 -> Column[{
                  Manipulate`Place[8]}]}, 
              Dynamic[$CellContext`opa2$$]], 0 -> PaneSelector[{1 -> Column[{
                  Manipulate`Place[9]}], 0 -> Column[{
                  Manipulate`Place[10]}]}, 
              Dynamic[$CellContext`opa2$$]]}, 
           Dynamic[$CellContext`opa3$$]]}, {
          Manipulate`Place[11]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp, 
              Invisible[$CellContext`temp]]]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {434., {117., 125.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa1$21149$$ = False, $CellContext`opa2$21150$$ = 
    False, $CellContext`opa3$21151$$ = False, $CellContext`Lp$21152$$ = 
    0, $CellContext`mg$21153$$ = 0, $CellContext`sita$21154$$ = 
    0, $CellContext`opa4$21155$$ = False, $CellContext`opa5$21156$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`Lp$$ = 0.5, $CellContext`mg$$ = 
        1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 
        1, $CellContext`opa3$$ = 1, $CellContext`opa4$$ = 
        0, $CellContext`opa5$$ = 0, $CellContext`sita$$ = 90}, 
      "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$21149$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$21150$$, False], 
        Hold[$CellContext`opa3$$, $CellContext`opa3$21151$$, False], 
        Hold[$CellContext`Lp$$, $CellContext`Lp$21152$$, 0], 
        Hold[$CellContext`mg$$, $CellContext`mg$21153$$, 0], 
        Hold[$CellContext`sita$$, $CellContext`sita$21154$$, 0], 
        Hold[$CellContext`opa4$$, $CellContext`opa4$21155$$, False], 
        Hold[$CellContext`opa5$$, $CellContext`opa5$21156$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`alfa$, $CellContext`L$, \
$CellContext`W$, 
         Null$, $CellContext`pa$, $CellContext`pb$, $CellContext`pc$, \
$CellContext`dp$, $CellContext`pb1$, $CellContext`pb2$, $CellContext`pb3$, \
$CellContext`pb4$, $CellContext`pb5$, $CellContext`pb6$, $CellContext`pb7$, \
$CellContext`pc1$, $CellContext`pc2$, $CellContext`pc3$, $CellContext`pc4$, \
$CellContext`pc5$, $CellContext`pc6$, $CellContext`pc7$, $CellContext`pta$, \
$CellContext`ptb$, $CellContext`ptc$, $CellContext`ptd$, $CellContext`pte$, \
$CellContext`dpx$, $CellContext`dpy$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`pca$, $CellContext`pcb$, $CellContext`pcc$, $CellContext`dwf0$, \
$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dw1$, $CellContext`dw2$, $CellContext`an$, $CellContext`m$, \
$CellContext`ma$, $CellContext`ma2$, $CellContext`label$}, \
($CellContext`size$ = 
          4.5; $CellContext`alfa$ = ($CellContext`sita$$/180) 
           Pi; $CellContext`L$ = $CellContext`size$; $CellContext`W$ = 
          0.1 $CellContext`L$; $CellContext`pa$ = {
           0, -$CellContext`W$}; $CellContext`pb$ = {
           0, $CellContext`W$}; $CellContext`pc$ = {(-$CellContext`W$)/
            3, $CellContext`W$ - $CellContext`W$/4}; $CellContext`dp$ = {
           0, $CellContext`W$/
            4}; $CellContext`pb1$ = $CellContext`pb$ - $CellContext`dp$; \
$CellContext`pb2$ = $CellContext`pb$ - 
           2 $CellContext`dp$; $CellContext`pb3$ = $CellContext`pb$ - 
           3 $CellContext`dp$; $CellContext`pb4$ = $CellContext`pb$ - 
           4 $CellContext`dp$; $CellContext`pb5$ = $CellContext`pb$ - 
           5 $CellContext`dp$; $CellContext`pb6$ = $CellContext`pb$ - 
           6 $CellContext`dp$; $CellContext`pb7$ = $CellContext`pb$ - 
           7 $CellContext`dp$; $CellContext`pc1$ = $CellContext`pc$ - \
$CellContext`dp$; $CellContext`pc2$ = $CellContext`pc$ - 
           2 $CellContext`dp$; $CellContext`pc3$ = $CellContext`pc$ - 
           3 $CellContext`dp$; $CellContext`pc4$ = $CellContext`pc$ - 
           4 $CellContext`dp$; $CellContext`pc5$ = $CellContext`pc$ - 
           5 $CellContext`dp$; $CellContext`pc6$ = $CellContext`pc$ - 
           6 $CellContext`dp$; $CellContext`pc7$ = $CellContext`pc$ - 
           7 $CellContext`dp$; $CellContext`pta$ = {0, 
           0}; $CellContext`pe = {$CellContext`L$, (-$CellContext`W$)/
            2}; $CellContext`r1$ = $CellContext`W$/
           8; $CellContext`ptb$ = $CellContext`pta$ - {$CellContext`W$/
            1.6, $CellContext`W$/
            1}; $CellContext`ptc$ = $CellContext`ptb$ + {(2/
              1.6) $CellContext`W$, 
             0}; $CellContext`ptd$ = $CellContext`ptb$ + {(-$CellContext`W$)/
             5, 0}; $CellContext`pte$ = $CellContext`ptc$ + {$CellContext`W$/
             5, 0}; $CellContext`r2$ = $CellContext`W$/
           4; $CellContext`pca$ = {$CellContext`L$, (-$CellContext`W$)/
             2 - $CellContext`r2$}; $CellContext`pcb$ = $CellContext`pca$ - {
           0, $CellContext`r2$} - {$CellContext`W$/1.6, 
            0}; $CellContext`pcc$ = $CellContext`pca$ - {
           0, $CellContext`r2$} + {$CellContext`W$/1.6, 
             0}; $CellContext`dpx$ = {(-$CellContext`W$)/5, 
            0}; $CellContext`dpy$ = {
           0, (-$CellContext`W$)/
            4}; $CellContext`pte2 = $CellContext`pte$ + $CellContext`dpx$; \
$CellContext`pte3 = $CellContext`pte$ + 
           2 $CellContext`dpx$; $CellContext`pte4 = $CellContext`pte$ + 
           3 $CellContext`dpx$; $CellContext`pte5 = $CellContext`pte$ + 
           4 $CellContext`dpx$; $CellContext`pte6 = $CellContext`pte$ + 
           5 $CellContext`dpx$; $CellContext`pte7 = $CellContext`pte$ + 
           6 $CellContext`dpx$; $CellContext`pte8 = $CellContext`pte$ + 
           7 $CellContext`dpx$; $CellContext`pte9 = $CellContext`pte$ + 
           8 $CellContext`dpx$; $CellContext`pte11 = $CellContext`pte$ + \
$CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte22 = $CellContext`pte$ + 
           2 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte33 = \
$CellContext`pte$ + 
           3 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte44 = \
$CellContext`pte$ + 
           4 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte55 = \
$CellContext`pte$ + 
           5 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte66 = \
$CellContext`pte$ + 
           6 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte77 = \
$CellContext`pte$ + 
           7 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte88 = \
$CellContext`pte$ + 
           8 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pte99 = \
$CellContext`pte$ + 
           9 $CellContext`dpx$ + $CellContext`dpy$; $CellContext`pcc2 = \
$CellContext`pte2 + {$CellContext`L$, 
             0}; $CellContext`pcc3 = $CellContext`pte3 + {$CellContext`L$, 
             0}; $CellContext`pcc4 = $CellContext`pte4 + {$CellContext`L$, 
             0}; $CellContext`pcc5 = $CellContext`pte5 + {$CellContext`L$, 
             0}; $CellContext`pcc6 = $CellContext`pte6 + {$CellContext`L$, 
             0}; $CellContext`pcc7 = $CellContext`pte7 + {$CellContext`L$, 
             0}; $CellContext`pcc8 = $CellContext`pte8 + {$CellContext`L$, 
             0}; $CellContext`pcc9 = $CellContext`pte9 + {$CellContext`L$, 
             0}; $CellContext`pcc11 = $CellContext`pte11 + {$CellContext`L$, 
             0}; $CellContext`pcc22 = $CellContext`pte22 + {$CellContext`L$, 
             0}; $CellContext`pcc33 = $CellContext`pte33 + {$CellContext`L$, 
             0}; $CellContext`pcc44 = $CellContext`pte44 + {$CellContext`L$, 
             0}; $CellContext`pcc55 = $CellContext`pte55 + {$CellContext`L$, 
             0}; $CellContext`pcc66 = $CellContext`pte66 + {$CellContext`L$, 
             0}; $CellContext`pcc77 = $CellContext`pte77 + {$CellContext`L$, 
             0}; $CellContext`pcc88 = $CellContext`pte88 + {$CellContext`L$, 
             0}; $CellContext`pcc99 = $CellContext`pte99 + {$CellContext`L$, 
             0}; $CellContext`fe = {$CellContext`Lp$$ $CellContext`L$, 
            0}; $CellContext`fi = $CellContext`fe + {$CellContext`mg$$ 
             Cos[$CellContext`alfa$], $CellContext`mg$$ 
             Sin[$CellContext`alfa$]}; $CellContext`sitaie = \
(($CellContext`mg$$/2) 1.2) Pi; Null$); 
        If[$CellContext`opa4$$ > 
          0, $CellContext`sitai = (-$CellContext`sitaie)/
           2, $CellContext`sitai = $CellContext`sitaie/2]; 
        If[$CellContext`opa4$$ > 
          0, $CellContext`sitae = $CellContext`sitaie/
           2, $CellContext`sitae = (-$CellContext`sitaie)/2]; $CellContext`rm = 
         0.5; If[$CellContext`opa4$$ > 
          0, $CellContext`mi = {$CellContext`rm 
             Cos[$CellContext`sitae + 
               Abs[$CellContext`sitae - $CellContext`sitai] 
                0.1], $CellContext`rm 
             Sin[$CellContext`sitae + 
               Abs[$CellContext`sitae - $CellContext`sitai] 
                0.1]} + $CellContext`fe, $CellContext`mi = {$CellContext`rm 
             Cos[$CellContext`sitae - 
               Abs[$CellContext`sitae - $CellContext`sitai] 
               0.1], $CellContext`rm 
             Sin[$CellContext`sitae - 
               Abs[$CellContext`sitae - $CellContext`sitai] 
               0.1]} + $CellContext`fe]; $CellContext`me = {$CellContext`rm 
            Cos[$CellContext`sitae], $CellContext`rm 
            Sin[$CellContext`sitae]} + $CellContext`fe; $CellContext`rfx6 = {
          Part[$CellContext`fi, 1] - Part[$CellContext`fe, 1], 
           0}; $CellContext`rfy6 = {
          0, Part[$CellContext`fi, 2] - 
           Part[$CellContext`fe, 2]}; $CellContext`rf6 = 
         0.5; $CellContext`mg6 = 
         Norm[$CellContext`rfy6] $CellContext`Lp$$; $CellContext`sitaie6 = \
(($CellContext`mg6/2) 1.2) Pi; 
        If[Part[$CellContext`rfy6, 2] > 
          0, $CellContext`sitai6 = -Pi + $CellContext`sitaie6/
            2, $CellContext`sitai6 = -Pi - $CellContext`sitaie6/2]; 
        If[Part[$CellContext`rfy6, 2] > 
          0, $CellContext`sitae6 = -Pi - $CellContext`sitaie6/
           2, $CellContext`sitae6 = -Pi + $CellContext`sitaie6/2]; 
        If[Part[$CellContext`rfy6, 2] > 
          0, $CellContext`mi6 = {$CellContext`rf6 
             Cos[$CellContext`sitae6 + 
               Abs[$CellContext`sitae6 - $CellContext`sitai6] 
                0.05], $CellContext`rf6 
             Sin[$CellContext`sitae6 + 
               Abs[$CellContext`sitae6 - $CellContext`sitai6] 
                0.05]} + $CellContext`pta$, $CellContext`mi6 = \
{$CellContext`rf6 
             Cos[$CellContext`sitae6 - 
               Abs[$CellContext`sitae6 - $CellContext`sitai6] 
               0.1], $CellContext`rf6 
             Sin[$CellContext`sitae6 - 
               Abs[$CellContext`sitae6 - $CellContext`sitai6] 
               0.1]} + $CellContext`pta$]; $CellContext`me6 = \
{$CellContext`rf6 Cos[$CellContext`sitae6], $CellContext`rf6 
            Sin[$CellContext`sitae6]} + $CellContext`pta$; 
        If[$CellContext`opa4$$ > 0, $CellContext`sitai7 = 
          Pi + $CellContext`sitaie/2, $CellContext`sitai7 = 
          Pi - $CellContext`sitaie/2]; 
        If[$CellContext`opa4$$ > 0, $CellContext`sitae7 = 
          Pi - $CellContext`sitaie/2, $CellContext`sitae7 = 
          Pi + $CellContext`sitaie/2]; 
        If[$CellContext`opa4$$ > 
          0, $CellContext`mi7 = {$CellContext`rm 
             Cos[$CellContext`sitae7 + 
               Abs[$CellContext`sitae7 - $CellContext`sitai7] 
                0.1], $CellContext`rm 
             Sin[$CellContext`sitae7 + 
               Abs[$CellContext`sitae7 - $CellContext`sitai7] 
                0.1]} + $CellContext`pta$, $CellContext`mi7 = \
{$CellContext`rm 
             Cos[$CellContext`sitae7 - 
               Abs[$CellContext`sitae7 - $CellContext`sitai7] 
               0.1], $CellContext`rm 
             Sin[$CellContext`sitae7 - 
               Abs[$CellContext`sitae7 - $CellContext`sitai7] 
               0.1]} + $CellContext`pta$]; $CellContext`me7 = \
{$CellContext`rm Cos[$CellContext`sitae7], $CellContext`rm 
            Sin[$CellContext`sitae7]} + $CellContext`pta$; $CellContext`rfax8 = \
$CellContext`rfx6; $CellContext`rfy8 = $CellContext`rfy6; $CellContext`rfby8 = \
($CellContext`rfy8 $CellContext`Lp$$) ($CellContext`L$/$CellContext`L$); \
$CellContext`rfay8 = $CellContext`rfy8 - $CellContext`rfby8; 
        If[$CellContext`opa4$$ < 
          1, $CellContext`rfby9 = {
           0, $CellContext`mg$$}, $CellContext`rfby9 = {
           0, -$CellContext`mg$$}]; $CellContext`rfay9 = -$CellContext`rfby9; 
        If[
          
          And[$CellContext`opa2$$ == 1, $CellContext`opa3$$ == 
           1], $CellContext`temp = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"A\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)  = ", 
             If[Part[$CellContext`rfy6, 2] < 0, 
              NumberForm[$CellContext`mg6, {3, 2}], 
              NumberForm[-$CellContext`mg6, {3, 2}]], 
             Spacer[2], "kN\[CenterDot]m", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfx6, 1], {3, 2}], 
             Spacer[2], "kN", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfy6, 2], {3, 2}], 
             Spacer[2], "kN"}]]; If[
          
          And[$CellContext`opa2$$ == 1, $CellContext`opa3$$ == 
           0], $CellContext`temp = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"A\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)  = ", 
             If[$CellContext`opa4$$ < 1, 
              NumberForm[$CellContext`mg$$, {3, 2}], 
              NumberForm[-$CellContext`mg$$, {3, 2}]], 
             Spacer[2], "kN\[CenterDot]m", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 0, 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 0}]]; If[
          And[$CellContext`opa2$$ == 0, $CellContext`opa3$$ == 
           1], $CellContext`temp = 
          Row[{"\!\(\*SubscriptBox[\n StyleBox[\"A\",\n\
FontSlant->\"Italic\"], \"x\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfax8, 1], {3, 2}], 
             Spacer[2], "kN", 
             Spacer[15], 
             "\!\(\*SubscriptBox[\n StyleBox[\"A\",\nFontSlant->\"Italic\"], \
\"y\"]\)\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfay8, 2], {3, 2}], 
             Spacer[2], "kN", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"B\", \"y\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfby8, 2], {3, 2}], 
             Spacer[2], "kN"}]]; If[
          
          And[$CellContext`opa2$$ == 0, $CellContext`opa3$$ == 
           0], $CellContext`temp = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 0, 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfay9, 2], {3, 2}], 
             Spacer[2], "kN", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"B\", \"y\"],\n  \
TraditionalForm],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)= ", 
             NumberForm[
              Part[$CellContext`rfby9, 2], {3, 2}], 
             Spacer[2], "kN"}]]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa1$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0}, {1.15 $CellContext`size$, 0}}], 
           
           Arrow[{{0, (-0.45) $CellContext`size$}, {
             0, 0.45 $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {1.2 $CellContext`size$, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             0.45 $CellContext`size$}]}; $CellContext`dwf1$ = {
           Opacity[0.5], 
           Lighter[Blue], 
           
           Rectangle[{
            0, (-0.5) $CellContext`W$}, {$CellContext`L$, 
             0.5 $CellContext`W$}], Black, 
           If[$CellContext`opa5$$ < 1, 
            Text[
            "A", $CellContext`pta$ + {
              0.25 $CellContext`W$, $CellContext`W$}]], 
           If[$CellContext`opa5$$ < 1, 
            Text[
            "B", $CellContext`pe + {(-0.25) $CellContext`W$, 
               1.5 $CellContext`W$}]]}; $CellContext`dwf2$ = {
           Opacity[$CellContext`opa2$$ (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Line[{$CellContext`pa$, $CellContext`pb$}], 
           Line[{$CellContext`pb$, $CellContext`pc$}], 
           Line[{$CellContext`pb1$, $CellContext`pc1$}], 
           Line[{$CellContext`pb2$, $CellContext`pc2$}], 
           Line[{$CellContext`pb3$, $CellContext`pc3$}], 
           Line[{$CellContext`pb4$, $CellContext`pc4$}], 
           Line[{$CellContext`pb5$, $CellContext`pc5$}], 
           Line[{$CellContext`pb6$, $CellContext`pc6$}], 
           Line[{$CellContext`pb7$, $CellContext`pc7$}]}; $CellContext`dwf3$ = {
           Opacity[(1 - $CellContext`opa2$$) (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Darker[Green], 
           
           Triangle[{$CellContext`pta$, $CellContext`ptb$, \
$CellContext`ptc$}], 
           Thickness[0.012], 
           Circle[$CellContext`pta$, $CellContext`r1$], 
           Thickness[0.005], 
           Line[{$CellContext`ptd$, $CellContext`pte$}], 
           Line[{$CellContext`pcc$, $CellContext`pcb$}], 
           Line[{$CellContext`pte$, $CellContext`pte11}], 
           Line[{$CellContext`pte2, $CellContext`pte22}], 
           Line[{$CellContext`pte3, $CellContext`pte33}], 
           Line[{$CellContext`pte4, $CellContext`pte44}], 
           Line[{$CellContext`pte5, $CellContext`pte55}], 
           Line[{$CellContext`pte6, $CellContext`pte66}], 
           Line[{$CellContext`pte7, $CellContext`pte77}], 
           Line[{$CellContext`pte8, $CellContext`pte88}], 
           Line[{$CellContext`pte9, $CellContext`pte99}], 
           Thickness[0.012], 
           Circle[$CellContext`pca$, $CellContext`r2$], 
           Thickness[0.005], 
           Line[{$CellContext`pcc2, $CellContext`pcc22}], 
           Line[{$CellContext`pcc3, $CellContext`pcc33}], 
           Line[{$CellContext`pcc4, $CellContext`pcc44}], 
           Line[{$CellContext`pcc5, $CellContext`pcc55}], 
           Line[{$CellContext`pcc6, $CellContext`pcc66}], 
           Line[{$CellContext`pcc7, $CellContext`pcc77}], 
           Line[{$CellContext`pcc8, $CellContext`pcc88}]}; $CellContext`dwf4$ = {
           Opacity[$CellContext`opa3$$], 
           Thickness[0.007], 
           Arrowheads[0.04], 
           Arrow[{$CellContext`fi, $CellContext`fe}], 
           If[Norm[$CellContext`fe - $CellContext`fi] > 0, 
            If[$CellContext`sita$$ < 180, 
             Text["F", $CellContext`fi + {0.15, 0.15}], 
             Text["F", $CellContext`fi + {0.15, -0.15}]]], Dashed, 
           Thickness[0.005], 
           Line[{{$CellContext`W$/3, 0}, {$CellContext`L$, 0}}], 
           PointSize[0.02], 
           Point[$CellContext`fe]}; $CellContext`dwf5$ = {
           Opacity[1 - $CellContext`opa3$$], 
           Thickness[0.007], 
           PointSize[0.02], 
           Point[$CellContext`fe], 
           Arrowheads[0.04], 
           Arrow[{$CellContext`me, $CellContext`mi}], 
           
           Circle[$CellContext`fe, $CellContext`rm, {$CellContext`sitai, \
$CellContext`sitae}], 
           If[$CellContext`mg$$ > 0, 
            If[$CellContext`opa4$$ > 0, 
             Text["M", $CellContext`me + {0, 0.7 $CellContext`W$}], 
             Text["M", $CellContext`me + {0, (-0.7) $CellContext`W$}]]], 
           Dashed, 
           Thickness[0.005], 
           Line[{{0, 0}, {$CellContext`L$, 0}}]}; $CellContext`dwf6$ = {
           
           Opacity[($CellContext`opa5$$ $CellContext`opa3$$) \
$CellContext`opa2$$], 
           Thickness[0.007], Red, 
           Arrowheads[0.04], 
           If[Norm[$CellContext`rfx6] > 0, 
            If[Part[$CellContext`rfx6, 1] > 0, 
             
             Arrow[{$CellContext`pta$ - $CellContext`rfx6, \
$CellContext`pta$}], 
             If[Norm[$CellContext`rfx6] < 0.3, 
              
              Arrow[{$CellContext`pta$, $CellContext`pta$ + $CellContext`rfx6 + \
{-0.2, 0}}], 
              
              Arrow[{$CellContext`pta$, $CellContext`pta$ + \
$CellContext`rfx6}]]]], 
           Arrow[{$CellContext`pta$ - $CellContext`rfy6, $CellContext`pta$}], 
           If[Norm[$CellContext`rfx6] > 0, 
            If[Part[$CellContext`rfx6, 1] < 0, 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pta$ + \
$CellContext`rfx6 + {0.2, 0.6 $CellContext`W$}], 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pta$ - \
$CellContext`rfx6 + {0.2, 0.6 $CellContext`W$}]]], 
           If[Norm[$CellContext`rfy6] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pta$ - \
$CellContext`rfy6 + {0.6 $CellContext`W$, 0}]], Cyan, 
           If[Part[$CellContext`rfx6, 1] > 0, 
            
            Circle[$CellContext`pta$ - $CellContext`rfx6, $CellContext`rf6, \
{$CellContext`sitai6, $CellContext`sitae6}], 
            
            Circle[$CellContext`pta$ + $CellContext`rfx6, $CellContext`rf6, \
{$CellContext`sitai6, $CellContext`sitae6}]], 
           If[Part[$CellContext`rfx6, 1] > 0, 
            
            Arrow[{$CellContext`mi6 - $CellContext`rfx6, $CellContext`me6 - \
$CellContext`rfx6}], 
            
            Arrow[{$CellContext`mi6 + $CellContext`rfx6, $CellContext`me6 + \
$CellContext`rfx6}]], 
           If[$CellContext`mg6 > 0, 
            If[Part[$CellContext`rfy6, 2] < 0, 
             Text[
             "\!\(\*SubscriptBox[\(M\), \(A\)]\)", {$CellContext`rf6 
                Cos[$CellContext`sitae6], $CellContext`rf6 
                Sin[$CellContext`sitae6]} + {0, (-0.7) $CellContext`rf6} - {
               Norm[$CellContext`rfx6], 0}], 
             Text[
             "\!\(\*SubscriptBox[\(M\), \(A\)]\)", {$CellContext`rf6 
                Cos[$CellContext`sitae6], $CellContext`rf6 
                Sin[$CellContext`sitae6]} + {0, 0.7 $CellContext`rf6} - {
               Norm[$CellContext`rfx6], 0}]]]}; $CellContext`dwf7$ = {
           
           Opacity[($CellContext`opa5$$ (
              1 - $CellContext`opa3$$)) $CellContext`opa2$$], 
           Thickness[0.007], Cyan, 
           Arrowheads[0.04], 
           Arrow[{$CellContext`mi7, $CellContext`me7}], 
           
           Circle[$CellContext`pta$, $CellContext`rm, {$CellContext`sitai7, \
$CellContext`sitae7}], 
           If[$CellContext`mg$$ > 0, 
            If[$CellContext`opa4$$ < 1, 
             Text[
             "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`me7 + {
               0, (-0.6) $CellContext`W$}], 
             Text[
             "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`me7 + {
               0, 0.6 $CellContext`W$}]]]}; $CellContext`dwf8$ = {
           
           Opacity[($CellContext`opa5$$ $CellContext`opa3$$) (
             1 - $CellContext`opa2$$)], 
           Thickness[0.007], Red, 
           Arrowheads[0.04], 
           If[Norm[$CellContext`rfax8] > 0, 
            If[Part[$CellContext`rfax8, 1] > 0, 
             
             Arrow[{$CellContext`pta$ - $CellContext`rfax8, \
$CellContext`pta$}], 
             If[Norm[$CellContext`rfax8] < 0.3, 
              
              Arrow[{$CellContext`pta$, $CellContext`pta$ + \
$CellContext`rfax8 + {-0.2, 0}}], 
              
              Arrow[{$CellContext`pta$, $CellContext`pta$ + \
$CellContext`rfax8}]]]], 
           If[Norm[$CellContext`rfax8] > 0, 
            If[Part[$CellContext`rfax8, 1] < 0, 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pta$ + \
$CellContext`rfax8 + {0, 0.6 $CellContext`W$}], 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pta$ - \
$CellContext`rfax8 + {0, 0.6 $CellContext`W$}]]], 
           
           Arrow[{$CellContext`pta$ - $CellContext`rfay8 + {
              0, (-$CellContext`W$)/2}, $CellContext`pta$ + {
              0, (-$CellContext`W$)/2}}], 
           If[Norm[$CellContext`rfay8] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pta$ - \
$CellContext`rfay8 + {0.8 $CellContext`W$, 0} + {0, (-$CellContext`W$)/2}]], 
           Arrow[{$CellContext`pe - $CellContext`rfby8, $CellContext`pe}], 
           If[Norm[$CellContext`rfby8] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe - \
$CellContext`rfby8 + {0.8 $CellContext`W$, 0}]]}; $CellContext`dwf9$ = {
           
           Opacity[($CellContext`opa5$$ (1 - $CellContext`opa3$$)) (
             1 - $CellContext`opa2$$)], 
           Thickness[0.007], Red, 
           Arrowheads[0.04], 
           
           Arrow[{$CellContext`pta$ + {
              0, (-$CellContext`W$)/2}, $CellContext`pta$ + {
              0, (-$CellContext`W$)/2} + $CellContext`rfay9}], 
           If[Norm[$CellContext`rfay9] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pta$ + \
$CellContext`rfay9 + {0.5 $CellContext`W$, 0} + {0, (-$CellContext`W$)/2}]], 
           Arrow[{$CellContext`pe - $CellContext`rfby9, $CellContext`pe}], 
           If[Norm[$CellContext`rfby9] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe - \
$CellContext`rfby9 + {0.6 $CellContext`W$, 0}]]}; $CellContext`dw1$ = 
         Graphics[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$}, 
           PlotRange -> {{(-0.65) $CellContext`size$, 
              1.5 $CellContext`size$}, {(-0.6) $CellContext`size$, 
              0.6 $CellContext`size$}}, ImageSize -> 280, Frame -> False]; 
        Show[$CellContext`dw1$]], 
      "Specifications" :> {{{$CellContext`opa1$$, 0, 
          Row[{"Coordinates visibility", 
            Spacer[60]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`opa2$$, 1, 
          Row[{"Types of Beam", 
            Spacer[90]}]}, {1 -> "Cantilever", 0 -> "Simple-Supported"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         2}, {{$CellContext`opa3$$, 1, 
          Row[{"Types of Loading", 
            Spacer[78]}]}, {1 -> "Force", 0 -> "Moment"}, ControlType -> 
         RadioButton, ControlPlacement -> 3}, {{$CellContext`Lp$$, 0.5, 
          Row[{"Position of Loading [m]", 
            Spacer[50]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 4}, {{$CellContext`mg$$, 1, 
          Row[{"Magnitude of Loading [kN]", 
            Spacer[28]}]}, 0, 2, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 5}, {{$CellContext`mg$$, 1, 
          Row[{"Magnitude of Loading [kN\[CenterDot]m]", 
            Spacer[15]}]}, 0, 2, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{$CellContext`sita$$, 90, 
          Row[{"Direction of Force [\[Degree]]", 
            Spacer[63]}]}, 0, 360, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 7}, {{$CellContext`sita$$, 90, 
          Row[{"Direction of Force [\[Degree]]", 
            Spacer[63]}]}, 0, 180, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 8}, {{$CellContext`opa4$$, 1, 
          Row[{"Direction of Moment", 
            Spacer[55]}]}, {1 -> "CCW", 0 -> "CW"}, ControlType -> 
         RadioButton, ControlPlacement -> 9}, {{$CellContext`opa4$$, 0, 
          Row[{"Direction of Moment", 
            Spacer[55]}]}, {0 -> "CW"}, ControlType -> RadioButton, 
         ControlPlacement -> 10}, {{$CellContext`opa5$$, 0, 
          Row[{"Reactive Force & Moment", 
            Spacer[28]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 11}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[5]}], 0 -> Column[{
                Manipulate`Place[6]}]}, 
            Dynamic[$CellContext`opa3$$]]}, {
           PaneSelector[{1 -> PaneSelector[{1 -> Column[{
                   Manipulate`Place[7]}], 0 -> Column[{
                   Manipulate`Place[8]}]}, 
               Dynamic[$CellContext`opa2$$]], 0 -> PaneSelector[{1 -> Column[{
                   Manipulate`Place[9]}], 0 -> Column[{
                   Manipulate`Place[10]}]}, 
               Dynamic[$CellContext`opa2$$]]}, 
            Dynamic[$CellContext`opa3$$]]}, {
           Manipulate`Place[11]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp, 
               Invisible[$CellContext`temp]]]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{1059., {212., 221.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "a11a8498-9b32-4203-9dfb-993f9b67734b"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.55 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 872}, 
  WindowMargins -> {{200, Automatic}, {16, Automatic}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 262, 7, 237, "Title"],
Cell[1751, 44, 1120, 17, 195, "Text"],
Cell[2874, 63, 33604, 665, 458, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature gupRW5Z1EjmN5D1eQisU@gyl *)
